---
title: <span class="badge builder"></span> Team
---
# <span class="badge builder"></span> Team

## Constructor

```python
Team(name: str)
```
## Methods

### <span class="badge object-method"></span> build

Builds the object.

```python
def build() -> team.Team
```

### <span class="badge object-method"></span> email

Email of the team.

```python
def email(email: str) -> typing.Self
```

### <span class="badge object-method"></span> name

Name of the team.

```python
def name(name: str) -> typing.Self
```

## See also

 * <span class="badge object-type-class"></span> [Team](./object-Team.md)
